@@ -87,6 +87,13 @@ message_blocker_approver_set_block_list(MessageBlockerApprover* self, const gcha
 		      g_strdup(account_name),
 		      block_list);
 }
+static int
+_blocker_cmp_with_globber(gconstpointer a, gconstpointer b)
+{
+  if(g_pattern_match_simple(a, b))
+    return 0;
+  return 1;
+}
 
 gboolean
 block_from_account(MessageBlockerApprover* self, const gchar* account_name, const gchar* targetID)
@@ -103,7 +110,7 @@ block_from_account(MessageBlockerApprover* self, const gchar* account_name, cons
     }
     GSList* list = g_slist_find_custom(block_list,
 				       targetID,
-				       (GCompareFunc)g_strcmp0);
+				       (GCompareFunc)_blocker_cmp_with_globber);
     if(list)
       return TRUE;
   }
