@@ -125,7 +125,7 @@ _gconf_block_list_changed(GConfClient* client,
 					  FALSE);
     }
   }
-  if(g_strcmp0(entry->key, DELETE_MSG_GCONF_PATH) == 0)
+  else if(g_strcmp0(entry->key, DELETE_MSG_GCONF_PATH) == 0)
   {
     plugin->priv->delete_msg = _read_delete_msg_setting();
   }
